from setuptools import setup

setup(name='udacity_gaus_bin_dist',
      version='0.1',
      description='Gaussian and Binomial distributions',
      author = 'Nils Mayat',
      packages=['udacity_gaus_bin_dist'],
      zip_safe=False)
